@@ -9,7 +9,7 @@ use Astro::Coord::ECI::TLE;
 use Carp;
 
 our @ISA = qw{ Astro::Coord::ECI::TLE };
-our $VERSION = '0.115_01';
+our $VERSION = '0.116_01';
 
 my $pkg = __PACKAGE__;
 
@@ -74,7 +74,8 @@ L<Astro::Coord::ECI::TLE|Astro::Coord::ECI::TLE>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
