@@ -5,7 +5,7 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '0.115_01';
+our $VERSION = '0.116_01';
 
 use Exporter qw{ import };
 
@@ -325,7 +325,8 @@ C<< abs( $want * $tolerance ) >> and then does a C<goto &tolerance>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
