@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Star;
 use strict;
 use warnings;
 
-our $VERSION = '0.115_01';
+our $VERSION = '0.116_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -330,6 +330,12 @@ star. A wide variety of coordinate representations is accommodated.
 This package requires B<Astro::SLA>, which in its turn requires the
 SLALIB library.
 
+=head1 SUPPORT
+
+Support is by the author. Please file bug reports at
+L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
+electronic mail to the author.
+
 =head1 AUTHOR
 
 Thomas R. Wyant, III (F<wyant at cpan dot org>)
