@@ -49,7 +49,7 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.115_01';
+our $VERSION = '0.116_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -442,6 +442,12 @@ sub next_quarter {
 	# thereof) of the calculated longitude.
 	$quarter = ceil( ( rad2deg( $lon ) + 359 ) / 90 ) % 4;
 	$season = $self->season( $year, $quarter );
+	# The above calculation gives the wrong $season between the
+	# December equinox and the end of the year. We fix it up here:
+	if ( $time - $season > SECSPERDAY * 180 ) {
+	    $year++;
+	    $season = $self->season( $year, $quarter );
+	}
 	# If we're a quarter too early, add one and repeat the
 	# calculation. We shouldn't have to do this more than once,
 	# since our maximum error even with the fudge factor is a day.
@@ -809,6 +815,12 @@ given day and location.
 L<Astro::SunTime|Astro::SunTime> by Rob Fugina, which provides
 functionality similar to B<Astro-Sunrise>.
 
+=head1 SUPPORT
+
+Support is by the author. Please file bug reports at
+L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
+electronic mail to the author.
+
 =head1 AUTHOR
 
 Thomas R. Wyant, III (F<wyant at cpan dot org>)
