@@ -123,7 +123,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.115_01';
+our $VERSION = '0.116_01';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -1551,7 +1551,7 @@ implemented herein.
 =head1 BUGS
 
 Bugs can be reported to the author by mail, or through
-L<https://rt.cpan.org/>.
+L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues/>.
 
 =head1 AUTHOR
 
